<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Выберите одно или несколько устройств</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>Переключиться в режим окна</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Переключиться в полноэкранный режим</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Установка завершена успешно.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Закройте это окно и снова запустите vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Получайте удовольствие от vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Выберите одно или несколько устройств</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Файловый менеджер не найден.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Пожалуйста установите файловый менеджер.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Запись не началась, недостаточно свободного места на диске.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Достигнут предел свободного дискового пространства.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Предел свободного дискового пространства</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Запись остановлена, недостаточно свободного места на диске.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>Весь экран</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Окно</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Файловый менеджер не найден</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Пожалуйста установите файловый менеджер.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Исходный код</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Переводы</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Выберите одно или несколько устройств</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Область экрана</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Область экрана</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Файловый менеджер не найден.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Пожалуйста установите файловый менеджер.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Лупа</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Лупа</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Отразить по горизонтали</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Отразить по вертикали</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Инвертировать</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Чёрно-белое в оттенках серого</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Чёрно-белое двухцветное</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Убрать рамку окна</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Параметры камеры</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Область экрана</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Лупа</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Обратный отсчёт</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Размер видео:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Свободное место на диске:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Время записи:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Кадры</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Видеокодек</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Формат</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Звуковой кодек</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Качество</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Не записывать указатель мыши</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Час</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Минута</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Запустить таймер</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Остановить запись после</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Часов</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Минут</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Секунд</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Путь к видео:</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Предел свободного дискового пространства</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Показывать значок в области уведомления</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Секунд до начала записи</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Проверить обновления</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Видео</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Доступно</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Недоступно</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Начать</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Камера</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Инвертировать</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Чёрно-белое в оттенках серого</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Воспроизвести последнюю запись</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Открыть папку</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Сворачивать окно перед началом записи</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Запускать свёрнутым</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Отразить по горизонтали</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Отразить по вертикали</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Чёрно-белое двухцветное</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Убрать рамку окна</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Сбросить все настройки при следующем запуске</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторское право и лицензия на использование изображений</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Мегабайт</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Запись с экрана</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Проигрыватель</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Журнал</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Автоматически</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Создать изображения вкладок </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Сведения о лицензии</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Включить</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Выключить</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Глобальные комбинации клавиш</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Назначенные комбинации клавиш.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Комбинация клавиш не назначена или назначена более одного раза.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Отображение фактически не работающей комбинации клавиш в качестве использующейся означает, что она используется другой программой</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Снимок</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Путь изображения</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Скрыть это окно</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Секунды ожидания перед записью</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Авторское право и лицензия на использование изображений</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Приостановить</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Во весь экран</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>Предыдущий кадр</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>Следующий кадр</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Без звука</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>Переместить меню</translation>
    </message>
</context>
</TS>